@@ -1,6 +1,6 @@
 import json
 import os
-from typing import Any, Dict
+from typing import Any, Dict, List
 
 import torch
 from torch import nn
@@ -43,7 +43,9 @@ class EncoderHead(nn.Module):
         """
         raise NotImplementedError()
 
-    def forward(self, input_vectors: torch.Tensor) -> torch.Tensor:
+    def forward(
+        self, input_vectors: torch.Tensor, meta: List[Any] = None
+    ) -> torch.Tensor:
         return self.transform(self.dropout(input_vectors))
 
     def get_config_dict(self) -> Dict[str, Any]:
